@@ -11,15 +11,21 @@ class FileCache:
             if self.exist:
                 self.mtime = os.stat(path).st_mtime
             else:
-                self.mtime = None
+                self.mtime = 0
 
     def update_info(self, path):
         self.cache[path] = self.fileinfo(path)
 
     def get_info(self, path):
-        if path not in self.cache:
+        # if path not in self.cache:
+        #    self.update_info(path)
+        # return self.cache[path]
+
+        try:
+            return self.cache[path]
+        except KeyError:
             self.update_info(path)
-        return self.cache[path]
+            return self.cache[path]
 
 
 fcache = FileCache()
