@@ -6,12 +6,27 @@ import fnmatch
 import functools
 import warnings
 import random
+from collections import defaultdict
 
 string_types = (type(b""), type(u""))
 
+
+def invert_depends_dictionary(depends_dictionary):
+    inverse_dictionary = {}
+    for target in depends_dictionary:
+        inverse_dictionary[target] = set()
+
+    for target in depends_dictionary:
+        deps_of_target = depends_dictionary[target]
+        for dep in deps_of_target:
+            inverse_dictionary[dep].add(target)
+    return inverse_dictionary
+
+
 def random_string(length):
     return "".join(random.choice("0123456789abcdefghijklmnopqrstuvwxyz") for i in range(length))
 
+
 def deprecated(reason):
     """
     This is a decorator which can be used to mark functions
@@ -253,3 +268,21 @@ def recursive_glob(treeroot, pattern):
         goodfiles = fnmatch.filter(files, pattern)
         results.extend(os.path.join(base, f) for f in goodfiles)
     return results
+
+
+class DefaultDictLazy(defaultdict):
+    def __init__(self, foo):
+        super().__init__()
+        self.foo = foo
+
+    def __missing__(self, key):
+        val = self.foo(key)
+        self[key] = val
+        return val
+
+
+canonical_path_lazy_store = DefaultDictLazy(lambda path: os.path.realpath(path))
+
+
+def canonical_path(path):
+    return canonical_path_lazy_store[path]
